==> dde-shell_1.0.10.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="162"/>
        <source>Indicator Style</source>
        <translation>Стиль індикатора</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="164"/>
        <source>Fashion Mode</source>
        <translation>Модний режим</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="169"/>
        <source>Efficient Mode</source>
        <translation>Практичний режим</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="175"/>
        <source>Alignment</source>
        <translation>Вирівнювання</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="206"/>
        <source>Left</source>
        <translation>Ліворуч</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="194"/>
        <source>Position</source>
        <translation>Розташування</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="179"/>
        <source>Align Left</source>
        <translation>Вирівняти ліворуч</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="181"/>
        <source>Align Top</source>
        <translation>Вирівняти вгору</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="188"/>
        <source>Align Center</source>
        <translation>Вирівняти за центром</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="196"/>
        <source>Top</source>
        <translation>Вгорі</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="201"/>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="211"/>
        <source>Right</source>
        <translation>Праворуч</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="217"/>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="219"/>
        <source>Keep Shown</source>
        <translation>Показувати постійно</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="224"/>
        <source>Keep Hidden</source>
        <translation>Приховувати</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="230"/>
        <source>Smart Hide</source>
        <translation>Розумне приховування</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="237"/>
        <source>Dock Settings</source>
        <translation>Параметри бічної панелі</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.36.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Стиль індикатора</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Модний режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Практичний режим</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Класичний режим</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Центрований режим</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Ліворуч</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Розташування</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Вгорі</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Праворуч</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Показувати постійно</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Приховувати</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Розумне приховування</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Параметри бічної панелі</translation>
    </message>
</context>
</TS>
